bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 33. Aventiure
___________________________________________________ #### Auentv wie Danchwart div maer ze hove #### sinen herren braht
| ### <Uil> lvote rief do Danchwart eime degene ### ir sizzet al ze lange brvoder Hagene ### iv vn– got von himele chlage ich vnser not ### ritter vn– knehte sint in der herberge tot
###### 2006 | ### Er rief im engegene wer hat daz getan ### daz hat der herre <Bloedel> vn– sine man ### ovch hat ers niht genozzen div wil ich iv sagen ### ich han im sin hovbet mit minen handen abe geslagen
###### 2007 | ### Daz ist ein schade kleine sprach aber Hagene ### swa man solhiv mære saget von degene ### ob er von rechen handen verlivset sinen lip ### in svln deste ringer klagen wætlichiv wip
###### 2008 | ### Nv saget mir lieber brvoder wie sit ir so rot ### ich wæn ir uon wnden lidet groze not ### ist er inder inme lande derz iv hat getan ### in erner der <vbel> tivfel ez mvz im an sin leben gan
###### 2009 | ### Ir seht mich wol gesunden min wat ist blvotes naz ### von ander mannen wnden ist mir geschehn daz ### der ich also manigen hivte han erslahen ### ob ich des swern solde ine chvndez nimmer gesagen
| ### Er sprach brvoder Danchwart so hvtet vns der tver ### vn– enlat der Hvnen einen chomen niht derfver ### ich wil reden mit den rechen des vns nv dwinget not ### vnser ingesinde lit vnverdienet hie tot
###### 2011 | ### Sol ich sin kamerære sprach do der kvene man ### also richen kvnegen ich wol gedienen chan ### <so> ich der stiegen nach den eren min ### den Chriemh' degenen chvnde leider niht gesin
###### 2012 | ### Mich nimt des michel wnder sprach do Hagene ### rvnen in disem gademe ### si wæn des lihte enbêrn der an der tver dort stat ### vn– ovch div hovemære gesaget den Bvrgonden hat
###### 2013 | ### Ich han gehort vil lange von Chriemh' sagen ### daz si ir hercen leide wolde niht vertragen ### nv trinchen wir die minne vn– gelten skvniges win ### der [72r]ivnge vogt der Hvnen der mvoz hie der erste sin
| ### Do slvoc daz kint Ortlieben Hagen der helt gvot ### daz im an dem swerte zer hende vloz daz blvot ### vnt daz des kindes hovbet spranch Chriemh' <in> ir schoz ### do hvop sich vnder degenen ein mort vil grimmech vn– groz
###### 2015 | ### Ovch slvoger den magetzogen einen swinden slac ### mit beiden sinen handen der Ortliebes pflac ### daz im daz hovbet schiere vor tischen nider lac ### ez was ein iæmerlicher lon den er dem magtzogen wach
###### 2016 | ### Er sach vor Ezeln tische einen spileman ### Hagen in sime zorne gahen dar began ### er slvog im vf der videlen ab die einen hant ### daz habe der boteschefte in der Bvrgonden lant
###### 2017 | ### Owe mir sprach Werbel der Ezeln spileman ### her Hagen von Tronege waz het ich iv getan ### ich kom vf groze triwe in iwer herren lant ### wie chlenche ich nv die doene sit ih nv verlorn han die hant
| ### Hagenen ahte ringe gevidelter nimmer mer ### do frvmt er in dem hvse div werch grimmen ser ### an den Ezelen rechen der er so manigen slvoc ### er braht ir in dem gademe zvo dem tode genvoc
###### 2019 | ### Volker sin geselle von tische spranch ### sin videlboge im lvote an siner hende erchlanc ### do videlte vngefvege der kunige spileman ### hey waz er im ze vienden der chvnen Hvnen gewan
###### 2020 | ### Do sprvngen von den tischen die drie kvnige her ### si woldenz gerne scheiden e des schaden wrde mer ### sine chvndenz mit ir sinnen do niht vnderstan ### do Volker vn– Hagene so sere weten began
###### 2021 | ### Do sach der vogt von Rine vngescheiden den strit ### do slvoc der fvrste selbe vil manige wnden wit ### dvrch die liehten ringe den vianden sin ### er was ein helt zen handen daz wart da grozlichen schin
| ### Do chom ovch zvo dem strite der starche Gernot ### ia frvomt er den Hvnen vil manigen helt tot ### mit dem scharpfen swerte daz im gap Rvdeger ### den Ezeln magen frvmrer div grozlichen ser
###### 2023 | ### Der ivnge svon frovn Vten zvo dem strite spranch ### sin wafen herrenliche dvrch die helme erchlanc ### den Ezeln rechen vzer Hvnen lant ### da tet vil michel wnder div Giselheres hant
###### 2024 | ### Swie frvom si alle wæren die kvnige vn– ovch ir man ### doch sah man Giselhere ze vorderest stan ### bi den vianden er was ein helt gvot ### er schvf da mit den wnden vil manigen nider in daz blvot
###### 2025 | ### Ovch werten sich vil sere die Ezeln man ### do sah man die geste howende gan ### mit den liehten swerten dvrch des kvniges sal ### do hort man allenthalben von strite grozlichen schal [72v]
| ### Do wolden die dar vzen mit frivnden sin dar in ### si namen an der stiegen vil kleinen gewin ### do wolden si dar inne vil gerne fvr die tver ### done lie der portenære ir deheinen dar fver
###### 2027 | ### Do hvop sich in der porte vil grozer der gedranc ### vn– ovch von den swerten vf helme lvoter klanc ### des chom der kvne Danchwart in vil starche not ### daz bedahte Hagene als im sin triwe gebot
###### 2028 | ### Vil lvte rief do Hagene Volkern an ### seht ir dort geselle minen brvoder stan ### vor hvnischen rechen vnder starchen slegen ### frivnt nert mir den brvoder ê wir vliesen den degn
###### 2029 | ### Daz tvon ich sicherlichen sprach der man ### er begvnde vil videlende dvrch den palas gan ### ein scharpfez <swert> im diche an siner hende erchlanc ### die rechen bi dem Rine sagten im des grozen danch
###### 2030 | ### Volker der vil chvene zvo Danchwarte sprach ### ir habt erliten hivte grozen vngemach ### mich bat iwer brvoder dvrch helfe zv zw gan ### welt ir nv sit dar vze so wil ich inrethalben stan
###### 2031 | ### Danchwart der vil snelle stvnt vzerhalp der tver ### do wert er in die stiegen swaz ir chom der fver ### des hort man waffen hellen an der helede hant ### sam tet ovch inrethalben Volker von Bvregonden lant
| ### Der chvne videlære rief zvo dem degene ### daz hvs ist wol beslozen frivnt Hagene ### ez ist also verschranchet div Ezeln tver ### von zweier rechen handen da <gent> wol tvsent rigel fver
###### 2033 | ### Do der starche Hagene die tver so sach behvot ### den schilt warf do zervcke der chvne degen gvot ### do erst begunder rechen siner frivnde leit ### sines zornes mvose engelten vil manic ritter gemeit
###### 2034 | ### Do der voget von Berne daz wnder reht ersach ### daz Hagene der starche so manigen helm brach ### der kunic der Amelvnge sprach vf einen banch ### er sprach hie schenchet Hagene daz aller wirsiste tranch
###### 2035 | ### Der wirt het groze sorge sin wip div het alsam ### waz man im lieber frivnde vor sinen ovgen nam ### wander von sinen vinden vil chvme da genas ### er saz vil angestliche waz half in daz er kunec was
| ### Chriemh' div frowe rief Dietrichen an ### nv hilf mir von dem sedele ritter von in dan ### dvrch aller fvrsten tvgende vz Amelvnge lant ### vn– erreichet mich dort Hagene ich han den tot an der hant
###### 2037 | ### Wie sol ich iv gehelfen sprach do Dietrich ### vil edeliv kuneginne nv sorge ich vmbe mich ### ez sint so sere erzvrnet die Guntheres man ### daz ich an disen citen gevriden niemen enchan
###### 2038 | ### Neina herre Dietrich vil edel ritter gvot ### laza hivte schinen den tvgentlichen [73r]mvt ### daz dv mir helfest hinnen oder ich belibe tot ### nv hilf mir vn– dem kvnige vz dirre angestlicher not
###### 2039 | ### Daz wil ich versvochen ob ich iv helfen chan ### wande ich in langen citen niht gesehn han ### so pitterlich erzvrnet manigen ritter gvot ### ia <sahe> dvrch die helme von swerten vliezen daz blvot
###### 2040 | ### Mit chraft begunde rufen der degen vz erchorn ### daz im sin stimme erlvote alsam ein wisents horn ### vn– daz der palas wite von siner chraft erdoz ### div sterche Dietriches was vil vnmæzliche groz
| ### Do gehorte Gvnther rvfen disen man ### in dem starchen stvrme losen er began ### er sprach Dietriches stimme ist in min ore chomen ### ich wæn im vnser degene etewen hie benomen
###### 2042 | ### Ich sihe in vf dem tische er winchet mit der hant ### ir frivnt vn– mage von Burgonden lant ### gehabt vf des strites lat hoeren vn– sehn ### waz hie Dietriche von vns ze schaden si geschehn
###### 2043 | ### Do der kunic Gunther bat vn– ovch gebot ### si habten vf mit swerten in des stvrmes not ### daz was gewalt vil grozer daz do niemen streit ### do reiten mit ein ander die kvnen rechen gemeit
###### 2044 | ### Er sprach vil edel Dietrich waz ist iv hie getan ### von den minen magen willen ich des han ### svne vn– bvze bin ich iv bereit ### swaz iv iemen tæte daz wær mir inneklichen leit
| ### Do sprach der herre Dietrich mir ist noch niht getan ### des ich schaden deheinen von iv mvge han ### wan lar mih von dem strite mit dem gesinde min ### daz wil ich vmbe ivch degene immer dienende sin
###### 2046 | ### Wie vleget ir so sere sprach do Wolfhart ### iane hat der videlære die tver nie so verspart ### wir entsliezen si so wite daz wir dar fvre gan ### nv swiget sprach her Dietrich ir habt den tivfel getan
###### 2047 | ### Do sprach der kunic Gvnther erlovben ich iv wil ### fvret vz dem hvse lvzzil oder vil ### ane mine vinde die svln hie bestan ### si habent mir zen Hvnen leides vil getan
###### 2048 | ### Der herre von Berne vnder einen arm besloz ### die edeln kuniginne der angest div was groz ### do fvrt er anderthalben Ezeln mit im dan ### ovch giengen mit im dannen sehs hvndert siner chvener man
| ### Do sprach der marcgrave der edel Rvdeger ### sol aber ozem hvse iemen chomen mer ### die iv doch dienen gerne daz lazet vns vernemen ### so sol ovch fride der stæte gvten frivnden immer zemen
###### 2050 | ### Des antwrte Giselher sime sweher zehant ### vride vn– svone si iv von uns bechant ### sit ir sit triwen stæte beide ir vn– iwer man ### svlt gemeinliche mit iwern frivnden hinnen gan
###### 2051 | ### Do der marcgrave gervmte den sal ### fvnf hundert vn– mere [73v]im volgten zetal ### die stiegen von dem hvose daz warn sine man ### von den der kvnec Gvnther vil grozen schaden sit gewan
###### 2052 | ### Do sach ein Hvnen reche Ezelen gan ### bidem Bernære genozzen wolders han ### dem gap der videlære einen swern slac ### daz im vor Ezeln fvezen daz hovbet schiere gelac
| ### Do der wirt des landes chom von dem hvse dan ### do cherte er sich hin widere vn– sach Volkeren an ### owe mir dirre geste daz ist ein grimmniv not ### daz alle mine frivnde svln vor in ligen tot
###### 2054 | ### Ach we der hochgecite sprach der kvnec her ### da vihter einer inne der heizet Volker ### alsam ein eber wilde vn– ist ein spileman ### ich danches mime heile daz ich dem valande entran
###### 2055 | ### Sine leyche lvtent vbele sine zvege die sint rot ### ia velent sine doene vil manigen helt tot ### ine weiz niht waz vns wize der selbe spileman ### wan ich gast neheinen nie so leiden gewan
###### 2056 | ### Zir herbergen giengen die rechen also her ### der herre von Berne vn– ovch Rvdeger ### sine wolden mit dem strite niht ze schaffen han ### vn– gebvten ovch ir degenen daz sis mit fride solden lan
###### 2057 | ### Vn– heten si getrowet alsolher swære ### daz in div von in beiden so chvnftich wære ### sine wærn von dem <hvse> niht so sanfte chomen ### si <heten> eine strovfe an den vil chvnen ê genomen
| ### Si heten die si wolden lazen vz dem sal ### <do> hvop sich inrethalben ein grozlicher schal ### die geste sere rachen daz in ê geschach ### Volker der vil chvene hey waz er liehter helme brach
###### 2059 | ### Sich cherte gein dem schalle Gunther der kunec her ### hort ir die doene Hagene die dort Volker ### mit den Hvnen videlet swer gegen der tvor gat ### ez ist ein roter anstrich den er zem videlbogen hat
###### 2060 | ### Mich riwet ane maze sprach do Hagene ### daz ich vor Volkere ie gesaz dem degene ### ich was sin geselle vn– ovch er der min ### vn– chom wir immer widere daz svln wir noch mit triwen sin
###### 2061 | ### Nv schowe kvnec Gvnther Volker ist dir holt ### er dienet willechliche din silber vn– <din> golt ### sin videlbogeim snidet dvrch den herten stal ### er brichet vf den helmen div liehten schinende mal
###### 2062 | ### Man gesach nie videlære so herlichen stan ### also der degen Volker hivte hat getan ### die sinen leyche hellent dvrch helm vn– dvrch den rant ### ia sol er riten gvtiv ros vn– tragen herlich gewant
| ### Swaz der Hvnen mage in dem hvse was gewesen ### der enwas nv deheiner dar inne genesen ### des was der schal geswiftet daz niemen mit in streit ### div swert von [74r]handen legeten die kvnen degene gemeit

<<< Übersicht <<< vorige Seite nächste Seite >>>